# Flickr CC-BY Sample Dataset for Dresden (Germany)

* this dataset includes sample data from Flickr
* only metadata from photos are included that were published using [CC-BY-Licenses](https://www.flickr.com/services/api/flickr.photos.licenses.getInfo.html)
* included license ids: 1, 2, 3, 5, 6, 7, 9, and 10
* original userids, photoids and links to Flickr are not included
* terms have been filtered based on top 1000 most occuring terms, based on user counts,
  this excludes only personal relevant terms/tags